==> redshift-1.0.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/redshift/CfnClusterParameterGroupProps.java <==
package software.amazon.awscdk.services.redshift;

/**
 * Properties for defining a `AWS::Redshift::ClusterParameterGroup`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.0 (build a586a1a)", date = "2019-07-11T14:09:51.527Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnClusterParameterGroupProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::Redshift::ClusterParameterGroup.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDescription();
    /**
     * `AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getParameterGroupFamily();
    /**
     * `AWS::Redshift::ClusterParameterGroup.Parameters`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Object getParameters();
    /**
     * `AWS::Redshift::ClusterParameterGroup.Tags`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.util.List<software.amazon.awscdk.core.CfnTag> getTags();

    /**
     * @return a {@link Builder} of {@link CfnClusterParameterGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnClusterParameterGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private java.lang.String _description;
        private java.lang.String _parameterGroupFamily;
        @javax.annotation.Nullable
        private java.lang.Object _parameters;
        @javax.annotation.Nullable
        private java.util.List<software.amazon.awscdk.core.CfnTag> _tags;

        /**
         * Sets the value of Description
         * @param value `AWS::Redshift::ClusterParameterGroup.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withDescription(final java.lang.String value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of ParameterGroupFamily
         * @param value `AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withParameterGroupFamily(final java.lang.String value) {
            this._parameterGroupFamily = java.util.Objects.requireNonNull(value, "parameterGroupFamily is required");
            return this;
        }
        /**
         * Sets the value of Parameters
         * @param value `AWS::Redshift::ClusterParameterGroup.Parameters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withParameters(@javax.annotation.Nullable final software.amazon.awscdk.core.IResolvable value) {
            this._parameters = value;
            return this;
        }
        /**
         * Sets the value of Parameters
         * @param value `AWS::Redshift::ClusterParameterGroup.Parameters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withParameters(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._parameters = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value `AWS::Redshift::ClusterParameterGroup.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withTags(@javax.annotation.Nullable final java.util.List<software.amazon.awscdk.core.CfnTag> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnClusterParameterGroupProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnClusterParameterGroupProps build() {
            return new CfnClusterParameterGroupProps() {
                private final java.lang.String $description = java.util.Objects.requireNonNull(_description, "description is required");
                private final java.lang.String $parameterGroupFamily = java.util.Objects.requireNonNull(_parameterGroupFamily, "parameterGroupFamily is required");
                @javax.annotation.Nullable
                private final java.lang.Object $parameters = _parameters;
                @javax.annotation.Nullable
                private final java.util.List<software.amazon.awscdk.core.CfnTag> $tags = _tags;

                @Override
                public java.lang.String getDescription() {
                    return this.$description;
                }

                @Override
                public java.lang.String getParameterGroupFamily() {
                    return this.$parameterGroupFamily;
                }

                @Override
                public java.lang.Object getParameters() {
                    return this.$parameters;
                }

                @Override
                public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
                    return this.$tags;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("description", om.valueToTree(this.getDescription()));
                    obj.set("parameterGroupFamily", om.valueToTree(this.getParameterGroupFamily()));
                    if (this.getParameters() != null) {
                        obj.set("parameters", om.valueToTree(this.getParameters()));
                    }
                    if (this.getTags() != null) {
                        obj.set("tags", om.valueToTree(this.getTags()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.redshift.CfnClusterParameterGroupProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::Redshift::ClusterParameterGroup.Description`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * `AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getParameterGroupFamily() {
            return this.jsiiGet("parameterGroupFamily", java.lang.String.class);
        }

        /**
         * `AWS::Redshift::ClusterParameterGroup.Parameters`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.Object getParameters() {
            return this.jsiiGet("parameters", java.lang.Object.class);
        }

        /**
         * `AWS::Redshift::ClusterParameterGroup.Tags`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.jsiiGet("tags", java.util.List.class);
        }
    }
}

==> redshift-1.1.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/redshift/CfnClusterParameterGroupProps.java <==
package software.amazon.awscdk.services.redshift;

/**
 * Properties for defining a `AWS::Redshift::ClusterParameterGroup`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.2 (build e881f16)", date = "2019-07-19T19:03:16.247Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnClusterParameterGroupProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::Redshift::ClusterParameterGroup.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDescription();
    /**
     * `AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getParameterGroupFamily();
    /**
     * `AWS::Redshift::ClusterParameterGroup.Parameters`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getParameters();
    /**
     * `AWS::Redshift::ClusterParameterGroup.Tags`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<software.amazon.awscdk.core.CfnTag> getTags();

    /**
     * @return a {@link Builder} of {@link CfnClusterParameterGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnClusterParameterGroupProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        private java.lang.String _description;
        private java.lang.String _parameterGroupFamily;
        @javax.annotation.Nullable
        private java.lang.Object _parameters;
        @javax.annotation.Nullable
        private java.util.List<software.amazon.awscdk.core.CfnTag> _tags;

        /**
         * Sets the value of Description
         * @param value `AWS::Redshift::ClusterParameterGroup.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withDescription(final java.lang.String value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of ParameterGroupFamily
         * @param value `AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withParameterGroupFamily(final java.lang.String value) {
            this._parameterGroupFamily = java.util.Objects.requireNonNull(value, "parameterGroupFamily is required");
            return this;
        }
        /**
         * Sets the value of Parameters
         * @param value `AWS::Redshift::ClusterParameterGroup.Parameters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withParameters(@javax.annotation.Nullable final software.amazon.awscdk.core.IResolvable value) {
            this._parameters = value;
            return this;
        }
        /**
         * Sets the value of Parameters
         * @param value `AWS::Redshift::ClusterParameterGroup.Parameters`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withParameters(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._parameters = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value `AWS::Redshift::ClusterParameterGroup.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withTags(@javax.annotation.Nullable final java.util.List<software.amazon.awscdk.core.CfnTag> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnClusterParameterGroupProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnClusterParameterGroupProps build() {
            return new CfnClusterParameterGroupProps() {
                private final java.lang.String $description = java.util.Objects.requireNonNull(_description, "description is required");
                private final java.lang.String $parameterGroupFamily = java.util.Objects.requireNonNull(_parameterGroupFamily, "parameterGroupFamily is required");
                @javax.annotation.Nullable
                private final java.lang.Object $parameters = _parameters;
                @javax.annotation.Nullable
                private final java.util.List<software.amazon.awscdk.core.CfnTag> $tags = _tags;

                @Override
                public java.lang.String getDescription() {
                    return this.$description;
                }

                @Override
                public java.lang.String getParameterGroupFamily() {
                    return this.$parameterGroupFamily;
                }

                @Override
                public java.lang.Object getParameters() {
                    return this.$parameters;
                }

                @Override
                public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
                    return this.$tags;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("description", om.valueToTree(this.getDescription()));
                    obj.set("parameterGroupFamily", om.valueToTree(this.getParameterGroupFamily()));
                    if (this.getParameters() != null) {
                        obj.set("parameters", om.valueToTree(this.getParameters()));
                    }
                    if (this.getTags() != null) {
                        obj.set("tags", om.valueToTree(this.getTags()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.redshift.CfnClusterParameterGroupProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::Redshift::ClusterParameterGroup.Description`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-description
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * `AWS::Redshift::ClusterParameterGroup.ParameterGroupFamily`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parametergroupfamily
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.String getParameterGroupFamily() {
            return this.jsiiGet("parameterGroupFamily", java.lang.String.class);
        }

        /**
         * `AWS::Redshift::ClusterParameterGroup.Parameters`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-parameters
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.Object getParameters() {
            return this.jsiiGet("parameters", java.lang.Object.class);
        }

        /**
         * `AWS::Redshift::ClusterParameterGroup.Tags`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html#cfn-redshift-clusterparametergroup-tags
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.jsiiGet("tags", java.util.List.class);
        }
    }
}
